VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CriticalSection"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' John Robbins
' Microsoft Systems Journal - August, 1997
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' FILE          :   CriticalSection.cls
' DESCRIPTION   :
'  A nice helper class that encapsulates critical section handling.
'  If you use this class to control access to data, make sure you set
'  up all the functions that use it with error handlers to make sure
'  that the Leave method is called after the enter.  In the following
'  example, g_CritSec is the critical section class.
'
'Public Sub DoSomething ( )
'  g_CritSec.Enter
'  On Error GoTo DoSomething_Error
'  ' Do some work here!
'  g_CritSec.Leave
'  Exit Sub
'
'DoSomething_Error:
'  g_CritSec.Leave
'End Sub
'
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Option Explicit

''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Class private variables
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Private m_CritSec As CRITICAL_SECTION

''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' FUNCTION        : Class_Initialize
' DISCUSSION      :
'  The initialization for the class.  This just initializes the private
'  CRITICAL_SECTION structure.
' PARAMETERS      :
'  None.
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Private Sub Class_Initialize()
   InitializeCriticalSection m_CritSec
End Sub

''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' FUNCTION        : Class_Terminate
' DISCUSSION      :
'  The termination for the class.  This just frees up the private
'  CRITICAL_SECTION structure.
' PARAMETERS      :
'  None.
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Private Sub Class_Terminate()
   DeleteCriticalSection m_CritSec
End Sub

''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' FUNCTION        : Enter
' DISCUSSION      :
'  Locks on the critical section by calling EnterCriticalSection.
' PARAMETERS      :
'  None.
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Public Sub Enter()
   EnterCriticalSection m_CritSec
End Sub

''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' FUNCTION        : Leave
' DISCUSSION      :
'  Unlocks the critical section by calling LeaveCriticalSection.
' PARAMETERS      :
'  None.
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Public Sub Leave()
   LeaveCriticalSection m_CritSec
End Sub
